@@ -19,8 +19,11 @@ from pygyver.etl.lib import read_table_schema_from_file
 from pygyver.etl.lib import bq_start_date
 from pygyver.etl.lib import bq_end_date
 from pygyver.etl.lib import set_write_disposition, set_priority
-from pygyver.etl.toolkit import date_lister
-from pygyver.etl.toolkit import validate_date
+from pygyver.etl.toolkit import (
+    date_lister,
+    flatten_df_columns,
+    validate_date
+)
 from pygyver.etl.gs import load_gs_to_dataframe
 from pygyver.etl.storage import GCSExecutor
 from pygyver.etl.db import DBExecutor
@@ -55,7 +58,7 @@ def read_sql(file, *args, **kwargs):
     ''' Read SQL file and apply arguments/keyword arguments.
 
     If dataset_prefix is a kwarg then this function is being used in a dry-run test.
-    In this case, the dataset_prefix is added to the dataset name and project names 
+    In this case, the dataset_prefix is added to the dataset name and project names
     are removed from the SQL.
 
     Args:
@@ -840,6 +843,32 @@ class BigQueryExecutor:
 
         return data
 
+    def execute_dml(self, sql=None, file=None, location='US', project=bq_default_project()):
+
+        job_config = bigquery.QueryJobConfig()
+
+        try:
+
+            sql = sql if sql else read_sql(file)
+        
+            job = self.client.query(sql, location=location, job_config=job_config)
+            
+            results = job.result()
+            
+            logging.info("%s - %s - %s rows effected (%s elapsed, %s B processed)",
+                job.statement_type,
+                job.state,
+                job.num_dml_affected_rows,
+                job.ended - job.started,
+                job.total_bytes_processed
+            )
+        
+        except Exception as e:
+            logging.error(e)
+            raise e
+
+        return
+
     def execute_file(self, file, project_id=bq_default_project(),
                      dialect='standard', *args, **kwargs):
         """ Executes a SQL file and loads it as a DataFrame.
@@ -1541,6 +1570,13 @@ class BigQueryExecutor:
                 raise AssertionError(msg)
 
     def assert_acceptance(self, sql, cte, output_table_name='expected_output', **kwargs):
+        """
+        Compares the target cte defined in the mock file with the output of the sql.
+
+        Notes:
+        - order of rows and columns doesn't matter
+        - only handles 1 layer of nesting
+        """
         try:
             sql_extract_output_table = "WITH {} ( SELECT * FROM `{}` )".format(cte, output_table_name)
 
@@ -1549,6 +1585,12 @@ class BigQueryExecutor:
             raise AssertionError("Bad SQL or CTE")
         composite_sql = "WITH {} ( {} )".format(cte, sql)
         df = self.execute_sql(composite_sql)
-        df = df.apply(lambda x: x.sort_values().values)
-        df_result = df_result.apply(lambda x: x.sort_values().values)
-        assert_frame_equal(df, df_result, check_like=True)
+
+        # flatten and sort - ignore column and row order
+        df = flatten_df_columns(df)
+        df = df[df.columns.sort_values()]
+        df = df.sort_values(list(df.columns)).reset_index(drop=True)
+        df_result = flatten_df_columns(df_result)
+        df_result = df_result[df_result.columns.sort_values()]
+        df_result = df_result.sort_values(list(df_result.columns)).reset_index(drop=True)
+        assert_frame_equal(df, df_result)
