@@ -189,6 +189,7 @@ def load_gs_to_json_schema(
         )
     with open(schema_path, "w") as f:
         json.dump(json_data, f, indent=4)
+        f.write("\n")
     print(f"Table schema file created at '{schema_path}.'")
 
 
@@ -258,7 +259,7 @@ def load_gs_to_sql_mock(
     if f_path:
         create_folder(f_path)
 
-    content = ",\n\n".join(ctes)
+    content = ",\n\n".join(ctes) + "\n"
     write_text_file(
         content=content,
         file_path=mock_path
