@@ -420,6 +420,7 @@ def _extract_table_data(
         evaluate_formulas=True
     )
     df = df.dropna(how="all")
+    df = df.reset_index(drop=True)
 
     return df
 
@@ -536,7 +537,7 @@ def _field_to_cte(
     if idx == 0:
         field_cte = f"{field_cte} AS {field[0]}"
 
-    return field_cte
+    return "\n\t\t" + field_cte
 
 
 def _row_to_cte(
@@ -556,13 +557,13 @@ def _row_to_cte(
     Returns:
         line_cte: row in sql cte format as str
     """
-    line = ", ".join([
+    line = ",".join([
         _field_to_cte(idx, r, schema_sql[r[0]]) for r in row.iteritems()
     ])
     if idx == 0:
-        line_cte = f"\tSELECT {line}"
+        line_cte = f"\tSELECT{line}"
     else:
-        line_cte = f"\tUNION ALL\n\tSELECT {line}"
+        line_cte = f"\tUNION ALL\n\tSELECT{line}"
 
     return line_cte
 
