@@ -21,63 +21,64 @@ class ZendeskDownloader:
     Class to download data from a Zendesk API endpoint specified by params.
     """
 
-    def __init__(self, start_date=None, uri=None, sideload=None, per_page=500, pagination=True):
+    def __init__(self, start_time=None, uri=None, sideload=None, per_page=None, limit=None, base_url="https://madecom.zendesk.com/"):
         """
         Construct all the necessary attributes for the ZendeskDownloader instance
         
         Args:
           uri (str): API endpoint.
-          start_date (str, optional): Timestamp format ('2018-12-31 22:45:32').
+          start_time (str, optional): Start time of the request
+          limit (int, optional): Per request limit of results returned, optional paramater for some endpoints.
           sideload (str, optional): Additional parameters seperated by &.
           per_page (int, optional): Size of page to fetch from the API.
-          pagination (bool, optional): Flag for if the endpoint has pagination.
+          base_url (str, optional): Base url of the api call.
           
         Examples:
           downloader = ZendeskDowloader(
             uri="api/v2/incremental/tickets",
-            start_date="2018-12-31 22:45:32",
+            start_time="2018-12-31 22:45:32",
             sideload="include=comment&include=metric_sets",
             per_page=200,
             pagination=True
           )
         """
         self.user = "analytics@made.com/token"
-        self.base_url = "https://madecom.zendesk.com/"
-        self.start_date = start_date
+        self.base_url = base_url
+        self.start_time = start_time
         self.sideload = sideload
         self.uri = uri
         self.per_page = per_page
-        self.pagination = pagination
+        self.limit = limit
         self.endpoint = None
         self.access_token = None
-        self.page_number = 0
         self.next_page = None
         self.retry = 0
         self.max_retry = 3
-        self.count = None
         self.params_list = []
         self.endpoint_params = ''
-        self.set_start_date()
+        self.finished=False
+        self.set_start_time()
         self.set_auth_token()
         self.set_auth()
         self.set_uri()
         self.set_start_time_param()
         self.set_per_page_param()
+        self.set_limit_param()
         self.set_sideload_param()
         self.set_endpoint_params()
         
-    def set_start_date(self):
-        """Convert `self.start_date` to epoch timestamp.
+    def set_start_time(self):
+        """Convert `self.start_time` to epoch timestamp.
 
         Raises:
-          ValueError: If `self.start_date` does not follow the format "%Y-%m-%d %H:%M:%S"
+          ValueError: If `self.start_time` does not follow the format "%Y-%m-%d %H:%M:%S"
         """
         pattern = "%Y-%m-%d %H:%M:%S"
-        if self.start_date is not None:
+        if self.start_time is not None:
             try:
-                logging.info("Start date: %s", self.start_date)
-                self.start_date = int(time.mktime(
-                    time.strptime(self.start_date, pattern)))
+                logging.info("Start date: %s", self.start_time)
+                self.start_time = int(time.mktime(
+                    time.strptime(self.start_time, pattern)))
             except ValueError:
                 raise ValueError("""Incorrect date format, must be '%Y-%m-%d %H:%M:%S',
                 eg. '2018-12-31 22:45:32'""")
@@ -112,18 +113,25 @@ class ZendeskDownloader:
           raise KeyError("URI param required")
             
     def set_start_time_param(self):
-        """Format and append start_time param to params_list if `self.start_date` is not None
+        """Format and append start_time param to params_list if `self.start_time` is not None
         """
-        if self.start_date:
-          param ="start_time={}".format(self.start_date)
+        if self.start_time:
+          param ="start_time={}".format(self.start_time)
           self.params_list.append(param)
             
     def set_per_page_param(self):
         """Format and append per_page param to params_list if `self.per_page` is not None
         """
-        if self.pagination:
+        if self.per_page:
           param = "per_page={}".format(self.per_page)
           self.params_list.append(param)
+
+    def set_limit_param(self):
+      """Append limit param to params_list if `self.limit` is not None
+      """
+      if self.limit:
+          param = "limit={}".format(self.limit)
+          self.params_list.append(param)
         
     def set_sideload_param(self):
         """Format and append sideload param to params_list if `self.sideload` is not None
@@ -147,50 +155,23 @@ class ZendeskDownloader:
         """Set `self.endpoint`. 
         
         The first call sets the endpoint based on values from the provided uri and params.
-        Subsequent calls set the endpoint based on the returned `next_page` value from the previous call.
+        Subsequent calls set the endpoint based on the returned next page value from the previous call (next_page/after_url).
         """
-        self.page_number = self.page_number + 1
         self.retry = 1
-        if self.page_number == 1:
+        if not self.endpoint:
             self.endpoint = self.base_url + self.uri + self.endpoint_params
             logging.info("Endpoint generated - {}".format(self.endpoint))
         else:
-            self.endpoint = self.data["next_page"]
-
-    def set_next_page(self):
-        """Set `self.next_page` if `self.data` contains a next_page key
-        """
-        page = self.data.get("next_page")
-        if page:
-            self.next_page = self.data['next_page']
-            
-    def set_count(self):
-        """Set `self.count` if `self.data` contains a next_page key
-        """
-        count = self.data.get("count")
-        if count:
-            self.count = self.data['count']
-            logging.info("API response returned {} rows".format(self.count))
-
-    def keep_running(self):
-        """Check if the API fetch process is complete
-        
-          If `self.page_number` is less than 0 then the first request has not yet been sent and so the process should continue.
-          If `self.pagination` is False then the endpoint does not have pagination and the process should stop after the first request
-          If `self.count` is less than `self.per_page` then the number of returned records is less then the records per page. This signifies that all records have been returned and the process should stop.
-
-        Returns:
-          bool: `True` if the process should stop `False` if the process should continue
-        """
-        if self.page_number > 0 and (self.pagination == False or self.count < self.per_page) :
-            return False
-        else:
-            return True
+            next_endpoint = self.data.get("next_page", self.data.get("after_url"))
+            if next_endpoint:
+              self.endpoint = next_endpoint
+            else:
+              self.finished = True
 
     def api_call(self):
         """ Make the API request and handle retry based response codes.
         
-        After each request update `self.count` with the number of records returned, `self.next_page` with the next_page endpoint provided in the response.
+        After each request update `self.endpoint` with the next_page endpoint provided in the response.
         If the rate limit is reached (429) process sleeps for period defined in the response.
 
         Raises:
@@ -199,8 +180,6 @@ class ZendeskDownloader:
         response = requests.get(url=self.endpoint, auth=self.auth)
         if response.status_code == 200:
             self.data = json.loads(response.content)
-            self.set_count()
-            self.set_next_page()
         elif response.status_code == 429:  # timed-out
             sleep_time = int(response.headers['retry-after'])
             logging.warning('Too many requests (429). Waiting %s secs to retry…', sleep_time)
@@ -217,12 +196,11 @@ class ZendeskDownloader:
             
     def download(self):
         """ Download API responses based on provided URI and params
-        
         Returns
           obj: Object of API response data
         """
-        if self.keep_running():
-            self.set_endpoint()
+        self.set_endpoint()
+        if not self.finished:
             self.api_call()
             responses = self.data
         else:
